ParseBaseIbanError

Enum ParseBaseIbanError 

pub enum ParseBaseIbanError {
    InvalidFormat,
    InvalidChecksum,
}
Indicates that the string does not follow the basic IBAN rules.

Example

An example of parsing invalid IBANs:

use iban::{BaseIban, ParseBaseIbanError};

// Invalid formatting because the spaces are in the wrong places
assert_eq!(
    "MR0 041 9".parse::<BaseIban>(),
    Err(ParseBaseIbanError::InvalidFormat)
);

// This IBAN follows the correct basic format but has an invalid checksum
assert_eq!(
    "MR00 0002 0001 0100 0012 3456 754".parse::<BaseIban>(),
    Err(ParseBaseIbanError::InvalidChecksum)
);

Variants



InvalidFormat

The string doesn’t have the correct format to be an IBAN. This can be because it’s too short, too long or because it contains unexpected characters at some location.



InvalidChecksum

The IBAN has an invalid structure.